@@ -1,6 +1,6 @@
 #! /usr/bin/perl -w
 
-# Copyright (c) 2003-2012 Henk Penning, all rights reserved.
+# Copyright (c) 2003-2013 Henk Penning, all rights reserved.
 # penning@uu.nl, http://www.cs.uu.nl/staff/henkp.html
 # Version 1.1 was donated to the Apache Software Foundation 2003 Jan 28.
 # Permission is hereby granted, free of charge, to any person obtaining a
@@ -28,7 +28,7 @@
 use strict ;
 
 our $PRG = 'mirmon' ;
-our $VER = "2.7" ;
+our $VER = "2.8" ;
 
 our $DEF_TIMEOUT = 300 ;
 our $HIST        = 14 ;
@@ -1720,7 +1720,7 @@ The url as given in the mirror list.
 
 =item B<age>
 
-The mirror's timestamp found by the last succesful probe,
+The mirror's timestamp found by the last successful probe,
 or 'undef' if no probe was ever successful.
 
 =item B<last_status>
@@ -1729,7 +1729,7 @@ The status of the last probe, or 'undef' if the mirror was never probed.
 
 =item B<last_ok_probe>
 
-The timestamp of the last succesful probe or 'undef'
+The timestamp of the last successful probe or 'undef'
 if the mirror was never successfully probed.
 
 =item B<probe_history>
@@ -1817,7 +1817,9 @@ and updates the state of the mirror.
 
 =begin html
 
-<A HREF="mirmon.html">mirmon(1)</A>
+<p>
+<a href="mirmon.html">mirmon(1)</a>
+</p>
 
 =end html
 
@@ -1831,30 +1833,33 @@ mirmon(1)
 
 =begin html
 
-  &copy; 2003-2012
-  <A HREF="http://www.staff.science.uu.nl/~penni101/">Henk P. Penning</A>,
-  <A HREF="http://www.uu.nl/faculty/science/EN/">Faculty of Science</A>,
-  <A HREF="http://www.uu.nl/">Utrecht University</A>
-  <BR>
-  mirmon-2.7 - Sat Dec 15 08:43:36 2012 ; henkp
+  <p>
+  &copy; 2003-2013
+  <a href="http://www.staff.science.uu.nl/~penni101/">Henk P. Penning</a>,
+  <a href="http://www.uu.nl/faculty/science/EN/">Faculty of Science</a>,
+  <a href="http://www.uu.nl/">Utrecht University</a>
+  <br />
+  mirmon-2.8 - Sat Jan  5 15:09:55 2013 ; henkp ;
+  <a href="http://validator.w3.org/check?uri=referer">verify html</a>
+  </p>
 
 =end html
 
 =begin man
 
-  (c) 2003-2012 Henk P. Penning
+  (c) 2003-2013 Henk P. Penning
   Faculty of Science, Utrecht University
   http://www.staff.science.uu.nl/~penni101/ -- penning@uu.nl
-  mirmon-2.7 - Sat Dec 15 08:43:36 2012 ; henkp
+  mirmon-2.8 - Sat Jan  5 15:09:55 2013 ; henkp
 
 =end man
 
 =begin text
 
-  (c) 2003-2012 Henk P. Penning
+  (c) 2003-2013 Henk P. Penning
   Faculty of Science, Utrecht University
   http://www.staff.science.uu.nl/~penni101/ -- penning@uu.nl
-  mirmon-2.7 - Sat Dec 15 08:43:36 2012 ; henkp
+  mirmon-2.8 - Sat Jan  5 15:09:55 2013 ; henkp
 
 =end text
 
